# IOSBuild - Example CMake Project

This directory contains a basic CMake project which may be 
used to test the IOSBuild library. The library includes no 
external dependencies and consists of a C struct and
function across a single source file and single header.